#
# spec file for package rtl8812au
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rtl8812au
Version:        5.6.4.2+git20200318.49e98ff
Release:        lp152.2.9.1
Summary:        Kernel driver for Realtek 802.11ac 8812au wifi cards
License:        GPL-2.0-only
Group:          System/Kernel
URL:            https://github.com/gordboy/rtl8812au-5.6.4.2
Source0:        %{name}-%{version}.tar.xz
Source1:        %{name}-preamble
Source2:        LICENSE
# PATCH-FIX-OPENSUSE fix-backported-ndo_select_queue.patch
Patch0:         fix-backported-ndo_select_queue.patch
BuildRequires:  %{kernel_module_package_buildreqs}
BuildRequires:  bc
BuildRequires:  binutils
BuildRequires:  fdupes
BuildRequires:  kernel-devel
BuildRequires:  kernel-source
BuildRequires:  module-init-tools
%kernel_module_package -p %{name}-preamble

%description
Kernel driver for Realtek 802.11ac 8812au wifi cards

The sources were obtained from https://github.com/gordboy/rtl8812au, which adaptes the official driver
released by Realtek to build on recent kernels.

The previous sources were obtained from https://github.com/diederikdehaas/rtl8812AU and 
https://github.com/maurossi/rtl8812au/ .

%package KMP
Summary:        Kernel driver for Realtek 802.11ac rtl8812au wifi cards
Group:          System/Kernel

%description KMP
Kernel driver for Realtek 802.11ac 8812au wifi cards

The sources were obtained from https://github.com/gordboy/rtl8812au, which adaptes the official driver
released by Realtek to build on recent kernels.

The previous sources were obtained from https://github.com/diederikdehaas/rtl8812AU and 
https://github.com/maurossi/rtl8812au/ .

%prep
%setup -q
%if 0%{?sle_version} == 150100
%patch0 -p1
%endif

set -- *
mkdir source
mv "$@" source/
cp "%{S:2}" source/
mkdir obj

%build
%ifarch %arm
export ARCH=arm
%endif
%ifarch aarch64
export ARCH=arm64
%endif
%ifarch %ppc ppc64 ppc64le
export ARCH=powerpc
%endif
for flavor in %{flavors_to_build} ; do
	cp -a source obj/$flavor
        pushd obj/$flavor
        sed -i -e "s,^KSRC [?:]= /lib/modules/\$(KVER)/build$,KSRC ?= %{_prefix}/src/linux-obj/%{_target_cpu}/$flavor," Makefile
        make %{?_smp_mflags} KSRC="%{_prefix}/src/linux-obj/%{_target_cpu}/$flavor"
        popd
done

%install
export INSTALL_MOD_PATH=%{buildroot}
export INSTALL_MOD_DIR=%{kernel_module_package_moddir}
kernel_version=`uname -r | sed -e "s/-[^-]*$//"`

echo ${kernel_version}
for flavor in %{flavors_to_build} ; do
        pushd obj/$flavor
        install -d %{buildroot}/lib/modules/${kernel_version}-${flavor}/${INSTALL_MOD_DIR}/
        install -p -m 644 8812au.ko %{buildroot}/lib/modules/${kernel_version}-${flavor}/${INSTALL_MOD_DIR}/
        popd
done

%files
%license source/LICENSE

%changelog
* Wed Oct  7 2020 Antonio Larrosa <alarrosa@suse.com>
- Fix replacement of KSRC in Makefile and also pass it as a
  parameter in case it changes again in the future. This fixes the
  module not being loadable by the kernel with "disagrees about
  version of symbol module_layout" (boo#1177250)
* Fri Apr  3 2020 Antonio Larrosa <alarrosa@suse.com>
- Update to 5.6.4.2+git20200318.49e98ff
  * Upstream changed the github repository, so changed it to since
    the previous one is now marked as obsolete
  * Works with (at least) a 5.6rc5 kernel
  * Added device USB IDs. Added regdb files.
  * Removed LED control, which was added for driver version 5.2.20
  * Users of NetworkManager need to add the following config option to
    /etc/NetworkManager/NetworkManager.conf:
    [device]
    wifi.scan-rand-mac-address=no
- Rebase patch fix-backported-ndo_select_queue.patch
* Thu Oct 31 2019 Antonio Larrosa <alarrosa@suse.com>
- Update to 5.2.20.2+git20190904.30d47a0
  * Fixes to make it work with kernel 5.3 (boo#1154539)
* Mon May 27 2019 Antonio Larrosa <alarrosa@suse.com>
- Fix _service file so it follows Factory policies
* Mon May 27 2019 Ryan Bach <romulasry@protonmail.com>
- Update to 5.2.20.2+git1558384184.6faa3ea
  * Fixes to make it work with kernel 5.1
  * Fixes to make it work with kernel 5.2
- Use obs_scm instead of depricated tar_scm service file for maintainability in the future
* Wed Jan 30 2019 alarrosa@suse.com
- Add fix-backported-ndo_select_queue.patch to fix building with
  SLE-15-SP1's 4.12 kernel with backported features from 4.19.
* Wed Jan 23 2019 alarrosa@suse.com
- Update to 5.2.20.2+git20190117.edcd447
  * Fixes to make it work with kernel 5.0
  * Fixes to make it work with kernel 4.20
  * Minor compiler warning turned off
* Thu Aug 30 2018 alarrosa@suse.com
- Add new supported hardware to the preamble file
* Thu Aug 30 2018 alarrosa@suse.com
- Update to version 5.2.20.2
  * Update phydm to improve TP stability
  * Support WiFi-HAL for Android 8
  * Build with kernel 4.19
- Drop patch allow-reproducible-builds.patch which was
  merged upstream by gordboy
- Fix build with Leap 15 by parsing correctly the lp150 suffix
* Fri Mar 30 2018 guillaume.gardet@opensuse.org
- Handle %%arm, aarch64 and ppc* properly
* Thu Mar  1 2018 alarrosa@suse.com
- Update to 5.2.20 from https://github.com/gordboy/rtl8812au. This
  includes support for kernel 4.15 and VHT extras.
- Dropped patches already upstream:
  * 0001-add-support-for-kernel-4.11.patch
  * 0002-add-support-for-kernel-4.12.patch
  * 0003-Fix-build-with-kernel-4.11.9.patch
  * 0004-Fix-for-Linux-kernel-4.12.5.patch
- Added patch:
  * allow-reproducible-builds.patch
- Added LICENSE file from upstream
* Thu Oct 19 2017 alarrosa@suse.com
- spec_cleaner
* Mon Oct  2 2017 alarrosa@suse.com
- Add 0001-add-support-for-kernel-4.11.patch
  0002-add-support-for-kernel-4.12.patch
  0003-Fix-build-with-kernel-4.11.9.patch
  0004-Fix-for-Linux-kernel-4.12.5.patch
  from https://github.com/maurossi/rtl8812au/ to fix
  builds with the kernel versions in TW
* Fri Sep 29 2017 alarrosa@suse.com
- Build fixes and add Supplements modalias
* Fri Nov 25 2016 alarrosa@suse.com
- Initial build
